@@ -134,7 +134,8 @@ class Log(object):
                   file=sys.stderr)
 
     def _log_to(self, msg: str, dest: list):
-        dest.append(msg if self.max_msg_len is None
+        dest.append(msg
+                    if self.max_msg_len is None or len(msg) <= self.max_msg_len
                     else msg[:self.max_msg_len]+"…")
 
     def message(self, msg: str):
